@@ -138,5 +138,5 @@ class MySQLExecuteEngine(ExecuteEngine):
 
 
 class MySQLTemplateEngine(TemplateEngine):
-    def __init__(self, conn: pymysql.Connection):
-        super().__init__(MySQLConnHandle(), MySQLExecuteEngine(), conn)
+    def __init__(self, conn: pymysql.Connection, auto_commit=True):
+        super().__init__(MySQLConnHandle(), MySQLExecuteEngine(), conn, auto_commit)
